package com.ruoyi.frequency.hosearch.service;

import java.util.List;

import com.ruoyi.controller.req.HotSearchListReq;
import com.ruoyi.frequency.hosearch.entity.HotSearch;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 热门搜索记录Service接口
 * 
 * @author liwenlong
 * @date 2024-03-19
 */
public interface HotSearchService extends IService<HotSearch>
{
    /**
     * 查询热门搜索记录
     * 
     * @param id 热门搜索记录主键
     * @return 热门搜索记录
     */
    public HotSearch selectHotSearchById(Long id);

    /**
     * 查询热门搜索记录列表
     * 
     * @param hotSearch 热门搜索记录
     * @return 热门搜索记录集合
     */
    public List<HotSearch> selectHotSearchList(HotSearch hotSearch);

    /**
     * 新增热门搜索记录
     * 
     * @param hotSearch 热门搜索记录
     * @return 结果
     */
    public int insertHotSearch(HotSearch hotSearch);

    /**
     * 修改热门搜索记录
     * 
     * @param hotSearch 热门搜索记录
     * @return 结果
     */
    public int updateHotSearch(HotSearch hotSearch);

    /**
     * 批量删除热门搜索记录
     * 
     * @param ids 需要删除的热门搜索记录主键集合
     * @return 结果
     */
    public int deleteHotSearchByIds(Long[] ids,Integer delFlag);

    /**
     * 查询热门搜索记录列表
     * @param req
     * @return
     */
    List<HotSearch> hotSearchList(HotSearchListReq req);

    /**
     * 记录搜索
     * @param hotSearch
     * @param isSuccess 是否搜索出数据
     */
    void addHotSearch(HotSearch hotSearch, Boolean isSuccess);
}
